@@ -63,12 +63,15 @@ def _tig(g, s, **kwargs):
     if g.G.is_directed() and g.G.q != 0 and ('method' not in kwargs or kwargs['method'] != 'exact'):
         raise Exception("Only method='exact' is currently supported for magnetic Laplacians.")
 
+    if s.ndim == 1:
+        s = s[..., np.newaxis]
+    assert s.ndim == 2, "Signal shape was {}".format(s.shape)
     tig = g.filter(s[..., np.newaxis], **kwargs)
-    if s.shape[1] == 1: # single node
-        tig = tig[:, np.newaxis, :]
+    if s.shape[1] == 1: # single signal
+        tig = tig[..., np.newaxis]
     if tig.ndim == 2: # single filter
         tig = tig[..., np.newaxis]
-    assert tig.shape == s.shape + (tig.shape[2],)
+    assert tig.shape == s.shape + (tig.shape[2],), "Tig shape was {}".format(tig.shape)
     return tig
 
 
@@ -174,11 +177,11 @@ def spectrogram(G, g=None, M=100, shifts=None, nodes=None, **kwargs):
     return spectr
 
 
-def kernelCentrality(G, g=None, nodes=None, **kwargs):
+def kernelCentrality(G, g=None, nodes=None, ord=None, **kwargs):
     if g is None:
         g = gsp.filters.Heat(G)
-    norm_sqr_func = lambda tig: (np.linalg.norm(tig, axis=0, ord=2)**2)
-    centr = nodeEmbedding(g, norm_sqr_func, nodes, **kwargs)
+    norm_func = lambda tig: np.linalg.norm(tig, axis=0, ord=ord)
+    centr = nodeEmbedding(g, norm_func, nodes, **kwargs)
     G.centr = centr
     return centr
 
@@ -490,7 +493,7 @@ def estimate_lmin(G, maxiter=2000):
 
 class LGraphFourier(gsp.graphs.fourier.GraphFourier):
     def compute_fourier_basis(self, recompute=False, spectrum_only=False):
-        if hasattr(self, '_e') and self._e and hasattr(self, '_U') and self._U and not recompute:
+        if hasattr(self, '_e') and self._e is not None and hasattr(self, '_U') and self._U is not None and not recompute:
             return
 
         assert self.L.shape == (self.N, self.N)
@@ -830,8 +833,8 @@ class BipartiteGraph(BigGraph):
 
 
 class StarGraph(gsp.graphs.Comet):
-    def __init__(self, N):
-        super().__init__(N, N-1)
+    def __init__(self, N, **kwargs):
+        super().__init__(N, N-1, **kwargs)
 
 
 class DirectedPath(BigGraph):
@@ -918,9 +921,9 @@ class ShiftedFilter(gsp.filters.Filter):
 
 
 class CustomFilter(gsp.filters.Filter):
-    def __init__(self, G, func, scales=1):
-        def kernel(x, s):
-            return func(x*s)
+    def __init__(self, G, funcs, scales=1):
+        if not hasattr(funcs, '__iter__'):
+            funcs = [funcs]
 
         if not hasattr(scales, '__iter__'):
             scales = [scales]
@@ -928,5 +931,6 @@ class CustomFilter(gsp.filters.Filter):
 
         kernels = []
         for s in scales:
-            kernels.append(lambda x, s=s: kernel(x,s))
+            for func in funcs:
+                kernels.append(lambda x, s=s, func=func: func(x*s))
         super().__init__(G, kernels)
